@@ -90,7 +90,7 @@ class IPX800:
 
             content = await response.json()
             raise IPX800RequestError(
-                "IPX800 API request error, error code", response.status
+                "IPX800 API request error %s: %s", response.status, content
             )
 
         except TimeoutError as exception:
@@ -181,30 +181,30 @@ class IPX800:
         self._objects_config = objects_config
 
     # Get ext or obj configs
-    def get_ext_config(self, ext_type, ext_number) -> dict:
+    def get_ext_config(self, ext_type: str, ext_number: int) -> dict:
         """Return the extension config."""
         extensions = [
             x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
         ]
         return extensions[ext_number - 1][API_CONFIG_PARAMS]
 
-    def get_ext_id(self, ext_type, ext_number) -> str:
+    def get_ext_id(self, ext_type: str, ext_number: int) -> int:
         """Return the unique extension id generated by the IPX."""
         extensions = [
             x for x in self.extensions_config if x[API_CONFIG_TYPE] == ext_type
         ]
         return extensions[ext_number - 1][API_CONFIG_ID]
 
-    async def get_ext_states(self, ext_type, ext_id) -> dict:
+    async def get_ext_states(self, ext_type: str, ext_id: int) -> dict:
         """Return all values of extension."""
         return await self._request_api(f"core/{ext_type}/{ext_id}")
 
-    def get_obj_config(self, obj_type, obj_number) -> dict:
+    def get_obj_config(self, obj_type: str, obj_number: int) -> dict:
         """Return the extension config."""
         extensions = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
         return extensions[obj_number - 1][API_CONFIG_PARAMS]
 
-    def get_obj_id(self, obj_type, obj_number) -> str:
+    def get_obj_id(self, obj_type: str, obj_number: int) -> str:
         """Return the unique object id generated by the IPX."""
         objs = [x for x in self.objects_config if x[API_CONFIG_TYPE] == obj_type]
         return objs[obj_number - 1][API_CONFIG_ID]
@@ -225,8 +225,10 @@ class IPX800:
         """Update an IO on the IPX."""
         await self._request_api(f"core/io/{id}", method="PUT", data={command: value})
 
-    async def update_ana(self, id: int, value: float) -> None:
+    async def update_ana(self, id: int, value) -> None:
         """Update an Analog on the IPX."""
+        if type(value) not in [int, float]:
+            raise IPX800RequestError("Ana value need to be a int or a float type.")
         await self._request_api(f"core/ana/{id}", method="PUT", data={"value": value})
 
     async def close(self) -> None:
